pro fd_master,mednorm=mednorm,scmstack=scmstack,medstack=medstack,$
              chopsig=chopsig,infiles=infiles,subfile=subfile,outfile=outfile,$
              no_plot=no_plot,sky=sky,uselog=uselog,no_savelog=no_savelog,$
              savelog=savelog

;no fits_datmask.pro usage in here yet...  it's somewhat unclear which
;is the best way to apply it.  I'll leave it out for now, but it will
;need to enter in here at some point.

;****** begin user input section

;restore saved inputs if desired
 huh = logcheck(uselog)
 if huh then begin
  restore,uselog & no_savelog = 1
 endif

;get main image names if not supplied
 if keyword_set(infiles) then f = infiles else begin
  f = dialog_pickfile(/multiple,/must_exist,$
                      title='Select files to go into processing image')
  infiles = f
 endelse

;check for filenames
 nf = n_elements(f)
 if f[0] eq '' then begin
  print,'ERROR in fd_master.pro: Missing file selection(s)!'
  retall
 endif

;check for desire to make a sky frame...  don't want skyframe? set sky = -2
 if not keyword_set(sky) then begin
  yup1 = dialog_message(/ques,'Is this intended to be a Sky Frame?')
 endif else begin
  if sky then yup1 = 'Yes' else yup1 = 'No'
 endelse

;if this is a sky frame, no normalizing and no dark/sky subtraction allowed
 if yup1 eq 'No' then begin
  sky = -2

;deal with median normalization...  don't want it?  set mednorm=-2
  if not keyword_set(mednorm) then begin
   yup1 = dialog_message(/ques,'Normalize result to its median value?')
   if yup1 eq 'Yes' then mednorm = 1 else mednorm = -2
  endif
  if mednorm then medtxt = 'Median-normed, ' else medtxt = ''

;check for desire to subtract dark/sky frame
  if not keyword_set(subfile) then begin
   subfile = 'NA'
   yup1 = dialog_message(/ques,'Do you want to subtract an existing'+$
                        ' sky or dark frame?')
  endif else begin
   if subfile ne 'NA' then begin
    ssub = size(subfile)
    if ssub[ssub[0]+1] ne 7 then yup1 = 'Yes' else begin
     if not file_test(subfile) then begin
      print,'ERROR in fd_master.pro: '+subfile+' does not exist!'
      yup1 = 'Yes'
     endif else yup1 = 'No'
    endelse
   endif else yup1 = 'No'
  endelse
  if yup1 eq 'Yes' then subfile = dialog_pickfile(/must_exist,$
     title='Select sky or dark frame to subtract')
 endif else begin
  sky = 1
  mednorm = -2
  subfile = 'NA'
 endelse

;for whatever reason, report whether or not an image will be subtracted
;don't want to subtract an image?  set subfile='NA'
 if subfile eq 'NA' then begin
  print,'Not subtracting dark or sky frame...'
  darktxt = ''
  dark = 0.
 endif else begin
  print,'Reading '+subfile
  darktxt = 'dark-(or sky-)subtracted '

;fits_datmask here?
  fits_read,subfile,dark,dhdr
 endelse

 if not keyword_set(no_plot) then no_plot = -2

;chopsig is number of std deviations to keep (from median)
 if not keyword_set(chopsig) then chopsig = 5.

;get desired merging method if not specified
 if not (keyword_set(scmstack) or keyword_set(medstack)) then begin
  yup1 = dialog_message(/question,'Use median stack method? (Default is '+$
     strtrim(chopsig,2)+' sigma-chopped mean)')
  if yup1 eq 'Yes' then begin
   medstack = 1 & scmstack = 0
  endif else begin
   scmstack = 1 & medstack = 0
  endelse
 endif else begin
  if not keyword_set(medstack) then medstack = 0
  if not keyword_set(scmstack) then scmstack = 0
 endelse

;****** end user input section

;Low memory procedure has three steps...
;We have to read in a few images early to get median (this may be only
;step, if median is chosen), then read in whole dataset 2 more
;times...  First to get the sigma map and then second to finally get the
;sigma chopped mean...  Total memory consumed: ~ 6 * (image data size).

;first, get median of first few images of im - "dark"

;if using median, this is the only step
 if scmstack then begin
  done = nf-1 < 4
  print,'Phase 1: Get median image of first few '+darktxt+'images'
 endif else begin
  done = nf-1
  print,'Computing median '+darktxt+'image of dataset...'
 endelse

 for i = 0,done do begin
  print,'Reading '+f[i]

;fits_datmask eventually?
  fits_read,f[i],im,hdr
  im = temporary(im) - dark
  im = temporary(im) > 0

;ditched pointers for Tom's sake...  I might be able to get around using them
;and still keep memory hoggishness to a minimum if I go crazy with the
;functions "temporary" and "delvarx"

;initialize arrays needed
  if i eq 0 then begin
   sz = size(im)
   x = make_array(done+1,sz[1],sz[2],type=sz[sz[0]+1],/nozero)
   med = fltarr(nf,/nozero)
  endif

;scale each image by it's own median value
  med[i] = median(im)
  if sky then begin
   x[i,*,*] = temporary(im) - med[i]
  endif else begin
   x[i,*,*] = temporary(im) / med[i]
  endelse
 endfor

;rescale whole array to median of medians...  use mean of medians here?
;get median image of cube and then ditch cube
 md = median(med[0:done])
 avg = median_stack2(temporary(x))
 if sky then avg = temporary(avg) + md else avg = temporary(avg) * md

;display median image
 if not no_plot then begin
  window,/free,xs=512,ys=512,title = 'fd_master.pro'
  tvscl,congrid(avg,256,256)>.5*md<1.5*md
 endif
 hlp,avg

;jump to the end and write the file if median was chosen.
;otherwise, move on to computing sigma map.
 if medstack then begin
  final = temporary(avg)
  sxaddpar,hdr,'HISTORY',medtxt+'median of '+strtrim(nf,2)+' '+darktxt+'images'
 endif else begin
  print,'Phase 1 Completed!'

;second, mush around each image and get std deviation image.
;From here on out, assume sigma chopped mean...
  print,'Phase 2: Get standard deviation image of '+darktxt+'images'

  for i = 0,nf-1 do begin

;initialize the sigma map
   if i eq 0 then std = avg * 0.

;read 'em all in and (re)compute one at a time
   print,'Reading '+f[i]
   fits_read,f[i],im,hdr
   im = (temporary(im) - dark) > 0
   med[i] = median(im)
   im = temporary(im) - avg
   std = temporary(std) + temporary(im)^2
  endfor

;take square root, chop skewed values at the median value,
;and make sure std has no zeros to keep from dividing by zero later.
  std = sqrt(temporary(std) / nf)
  smed = median(std) & smin = min(std[where(std gt 0)])
  std = temporary(std) > smin < smed

;display sigma map
  if not no_plot then tvscl,congrid(std,256,256)>0<smed,256,0,/dev
  hlp,std

  print,'Phase 2 Completed!'

;third, chop high sig values, keep mask tally, and make final
;sigma-chopped mean
  print,'Phase 3: Mask values beyond +/- '+strtrim(chopsig,2)+$
        ' standard deviations and recompute final "mean" image'

;Read 'em in and (re)compute again...
  for i = 0,nf-1 do begin
   print,'Reading '+f[i]
   fits_read,f[i],im,hdr
   im = (temporary(im) - dark) > 0
   check = abs(im-avg) / std
   if i eq 0 then begin
    final = im * 0.
    tempmask = where(check gt chopsig,nbad)
    mask = tempmask
   endif else begin
    tempmask = where(check gt chopsig,nbad)
    mask = [temporary(mask),tempmask]
    w = where(mask ge 0,nchk)
    if nchk gt 0 then mask = temporary(mask[w])
   endelse
   if nbad gt 0 then im[tempmask] = 0.
   final = temporary(final) + temporary(im)
  endfor

;don't need these anymore
  delvarx,avg,std,check,dark

;calculate number of values used for each pixel using mask tally
  norm = final * 0. + nf
  nbad = n_elements(mask)
  if mask[0] ne -1 then for i=0l,nbad-1 do norm[mask[i]]=norm[mask[i]]-1

;any positions that were all excluded are bad pixels...  zero them out,
;then set norm at that position to 1 to keep from dividing by zero.
  w = where(norm le 0,nbad)
  if nbad gt 0 then begin
   norm[w] = 1
   final[w] = 0.
  endif

;display norm
  if not no_plot then tvscl,congrid(norm,256,256)>1<nf,0,256,/dev
  hlp,norm

;get final mean!  WOO HOO!!
  final = temporary(final) / temporary(norm)

  print,'Phase 3 Completed!'
  sxaddpar,hdr,'HISTORY',medtxt+strtrim(chopsig,2)+' sigma-chopped mean of '+$
           strtrim(nf,2)+' '+darktxt+'images'
 endelse

;normalize image to median if desired
 scl = median(final)
 if mednorm then begin
  final = temporary(final) / scl
  scl = 1
 endif

;display final result, whichever method was used
 if not no_plot then tvscl,congrid(final,256,256)>.5*scl<1.5*scl,256,256,/dev
 hlp,final

;get filename if not specified
 if not keyword_set(outfile) then begin
  yup1 = 'No'
  while yup1 eq 'No' do begin
   outfile = dialog_pickfile(title='Save resulting image as?')
   if outfile eq '' then begin
    print,'Cancelling...'
    retall
   endif
   if not file_test(outfile) then yup1 = 'Yes' else yup1 = $
      dialog_message(/question,outfile+' exists...  Overwrite?')
  endwhile
 endif else yup1 = 'Yes'

;write the result to disk and end
 if yup1 eq 'Yes' then begin
  print,'Writing '+outfile

;fits_datmask here???
  fits_write,outfile,final,hdr
 endif

;****** I lied, a little user input section here too

;check and write log if it's called for
 huh = logcheck(savelog,/savelog,no_savelog=no_savelog)
 if huh then save,filename=savelog,infiles,outfile,subfile,mednorm,chopsig,$
    scmstack,medstack,no_plot,sky

;****** end user input section

end
