;+
;    name:
;       dysat.pro
;
;    purpose:
;       This function dynamically sets the saturation level for one pixel based 
;	on the tolerance level specified.
;
;    calling sequence:
;       result = dysat(x,y,tol)
;
;    inputs:
;  	x = sorted array of integration times
;       y = pixel values corresponding to x sorted using the sort(x) function
;       tol = set to slope value that defines saturation level
;
;    output:
;	time that saturation level for that pixel is reached
;
;    called programs:
;	(NONE)
;
;    history:
;       written 5-29-01: R. Gutermuth
;
;-


function dysat,x,y,tol

 mn = min(x)
 grr1 = where(x gt mn,n1)
 if n1 gt 0 then secmin = min(x[grr1]) > mn else return,mn
 
 nx = n_elements(x)
 done = x[nx-1]

 i = 0
 basex = x[i]

 while i lt nx do begin

  b = i
  check = x[i]

  while check eq basex do begin
   i = i + 1
   if i lt nx then check = x[i] else check = basex+1
  endwhile

  out = mean(y[b:i-1])

  if b gt 0 then slp = (out - base)/rn else slp = tol+1

  base = out

  if slp le tol then begin
   i = nx
  endif else begin
   rn = check - basex
   done = basex
   basex = check
  endelse

 endwhile

 if done le secmin then done = min(x)
 return,done

end

