;+
;   name:
;        rob_reg.pro
;
;   purpose:
;       this function is used to call rob_reg_gui.pro and to use its output
;       to compute the offset between two images given the subsections
;       chosen by the user in rob_reg_gui.pro.
;
;   calling sequence:
;       result = rob_reg(master,slave)
;
;   inputs:
;       master = master image array
;       slave = slave image array
;
;   keywords:
;       redo = set to make rob_reg_gui.pro have a REDO button
;              which makes assemble.pro switch back to the previous
;              iteration of mosaicing
;       coadd = set to circumvent rob_reg_gui.pro, using the previous
;               selection instead of making a new one.
;       scl = not used by user...  a keyword used to pass scaling information
;             around rob_reg.pro, rob_reg_gui.pro, assemble.pro, and
;             rob_assemble.pro
;
;   output:
;       result = (two element vector) total x and y offset between
;                master and slave
;
;   called programs:
;       rob_reg_gui.pro
;       xyoff.pro
;
;   history:
;       written 6-12-01: R. Gutermuth
;       7-2-01: changed output to include "persistent scaling" of
;               images from call to call (RAG)
;       6-12-02: ditched temp file usage for data transfer, using pointers 
;                instead (RAG)
;
;-


function rob_reg,master,slave,redo=redo,coadd=coadd,scl=scl;,test=test

 if not keyword_set(coadd) then begin
  in = rob_reg_gui(master,slave,redo=redo,scl=scl);,test=test)
 endif else in = coadd

; in = fltarr(2,6,/nozero)

; if file_test('~/anger.tmp') then begin
;  openr,one,'~/anger.tmp',/get
;  readu,one,in
;  free_lun,one
 if in[0,3] eq 1 then begin
  mp = master[in[0,0]:in[0,1],in[1,0]:in[1,1]]
  sp = slave[in[0,0]+in[0,2]:in[0,1]+in[0,2],in[1,0]+in[1,2]:in[1,1]+in[1,2]]
  sz = size(mp)
  ss = xyoff(mp,sp,sz[1],sz[2])
  out = [ss[0]-in[0,2],ss[1]-in[1,2],in[1,3]]
 endif else out='REDO'
; endif else begin
;  print,'ERROR in rob_reg.pro: Where is anger.tmp?!'
;  retall
; endelse

 if not keyword_set(scl) then scl = fltarr(2,2)
 scl[0,*] = in[*,4] & scl[1,*] = in[*,5]

 coadd = in

 return,out

end


