;..........................................................................
;
;   addcube
;
;   This function adds a spectra to the common variable "datacube" to a 2nd
;   datacube.  Currently on works on 3D data cubes (without atmospheric
;   correction information). It assumes a blanking value of < -100.
;
;   It places each spectra onto the nearest point in the specified
;   the lb grid, and a linear interpolation is used to align the input
;   spectrum with the specified velocity grid.
;
;   Parameters:  l = vector containing l values for datacube
;                b = vector containing b values for datacube
;                v = vector containing velocity values for datacube
;                incube = cube containing data to be inserted into datacube
;	         inl = vector containing l values for datacube
;		 inb = vector containing b values for datacube
;		 inv = vector containing v values for datacube
;
;   1-21-98: S. T. Megeath
;..........................................................................

pro addcube,l,b,v,incube,inl,inb,inv

; declare variables in common with data generated by scans program
@scans.cb

; determine size of array
  xpix = n_elements(l)
  ypix = n_elements(b)
  vpix = n_elements(v)

; determine size of array
  xinpix = n_elements(inl)
  yinpix = n_elements(inb)
  vinpix = n_elements(inv)

; determine step size in datacube
  stepl = l[1]-l[0]
  stepb = b[1]-b[0]

; loop through each spectrum in incube array, and find x and y position 
; (in units of pixels) of the spectra in the datacube array.

  for i = 0,xinpix-1 do begin 
    for j = 0,yinpix-1 do begin
      x = (inl[i]-l[0])/stepl
      y = (inb[j]-b[0])/stepb
      xfix = fix(x+0.5)
      yfix = fix(y+0.5)
      spect = incube[*,i,j]
      if (abs(x-xfix) le match and abs(y-yfix) le match $ 
          and spect[0] gt -100) then begin
        pix = interp_velocity_mini(v,inv)
        datacube[*,xfix,yfix] = interpolate(spect,pix)
      endif
    endfor
  endfor

  return

end
