;-----------------------------------------------------------
;
;	convert_nearest
;
;	function called by "convert_map.pro".   This subroutine
;	implements the nearest neighbour regridding of the data
;
;	Primary author: S. T. Megeath
;
;	History:
;
;	5-9-2000 - 1st version released
;
;------------------------------------------------------------

function convert_nearest,data,x,y,xnew,ynew,conversion

; set size of map in x and y direction
  xsize = n_elements(x)	
  ysize = n_elements(y)	
  x_exp = rebin(x,2.*xsize)
  y_exp = rebin(y,2.*ysize)
  data_exp = rebin(data,xsize*2.,ysize*2.,/sample)
  xnew_size = n_elements(xnew)
  ynew_size = n_elements(ynew)
  xnew_exp = rebin(xnew,2.*xnew_size)
  ynew_exp = rebin(ynew,2.*ynew_size)
  datanew = replicate(-100.,2*xnew_size,2*ynew_size)
  masknew = replicate(0.,2*xnew_size,2*ynew_size)
  data_reb = fltarr(xnew_size,ynew_size)
  mask_reb = fltarr(xnew_size,ynew_size)

; loop through each element in the converted coordinate, find
; nearest pixel in X and Y, and put nearest pixel in the converted
; image.

  for i=0,xsize*2-1 do begin
    for j=0,ysize*2-1 do begin
      convert,x_exp[i],y_exp[j],xconv,yconv,conversion
      inew = where(abs(xnew_exp-xconv) eq min(abs(xnew_exp-xconv)))
      jnew = where(abs(ynew_exp-yconv) eq min(abs(ynew_exp-yconv)))
      if (inew[0] gt -1 and jnew[0] gt -1) then begin
        for ii=0,n_elements(inew)-1 do begin
          for jj=0,n_elements(jnew)-1 do begin
            datanew[inew[ii],jnew[jj]] = data_exp[i,j]
            masknew[inew[ii],jnew[jj]] = masknew[inew[ii],jnew[jj]]+1
          endfor
         endfor
       endif
    endfor
  endfor
  
  for i=0,xnew_size-1 do begin
    for j=0,ynew_size-1 do begin
      data_reb[i,j] = datanew[2*i,2*j]*masknew[2*i,2*j]+$
                 datanew[2*i+1,2*j]*masknew[2*i+1,2*j]+$
 		 datanew[2*i,2*j+1]*masknew[2*i,2*j+1]+$
                 datanew[2*i+1,2*j+1]*masknew[2*i+1,2*j+1]
      mask_reb[i,j] = masknew[2*i,2*j]+masknew[2*i+1,2*j]+$
                      masknew[2*i,2*j+1]+masknew[2*i+1,2*j+1]
    endfor
  endfor
  index = where(mask_reb gt 0)
  data_reb[index] = data_reb[index]/mask_reb[index]
  return,data_reb

end

















