;
;	clusteroffset
;
;	this program creates an AOR with a cluster offset target ussing a input coordinate
;	file.
;
;	v3 - set up for June 30, 2003 submission of Orion and NGC2264 data.
;
;	S. T. Megeath - last modified June 26, 2003.
;
;------------------------------------------------------------------------------------------

function clusteroffset_v3,coords_abs,outfile = outfile,exist=exist,label=label,$
		       target_name=target_name,$
			fov2=fov2,timing_file=timing_file

	if NOT keyword_set(label) then label = "IRAC-0001"
	if NOT keyword_set(target_name) then target_name = "none"

	mean_ra = mean(coords_abs[0,*])
	mean_dec = mean(coords_abs[1,*])

	coords_off = coords_abs
	coords_off[0,*]  = 3600.*(coords_abs[0,*]-mean_ra)*cos(2.*!pi*mean_dec/360.)
	coords_off[1,*]  = 3600.*(coords_abs[1,*]-mean_dec)


	if keyword_set(outfile) then begin
	  if NOT keyword_set(exist) then openw,1,outfile
	  if keyword_set(exist) then openw,1,outfile,/append

          if NOT keyword_set(exist) then  printf,1,'HEADER: FILE_VERSION=7.0, STATUS = PROGRAM'
  	  printf,1,"     AOT_TYPE:  IRAC Mapping"
	  printf,1,label,format = '("     AOR_LABEL:  ",a)'
	  printf,1,"    AOR_STATUS:  new"
	  printf,1," "
	  printf,1," MOVING_TARGET:  NO"
	  printf,1,"   TARGET_TYPE:  FIXED CLUSTER - OFFSETS"
	  printf,1,target_name,format = '("   TARGET_NAME:  ",a)'
	  printf,1,"  COORD_SYSTEM:  Equatorial  J2000"
          printf,1,mean_ra,mean_dec,$
          format = '("     POSITION1:  RA_LON=",f9.6,"d,  DEC_LAT=",f9.6,"d")'
	  inc=1
	  for i = 0,n_elements(coords_off[0,*])-1 do begin	
            inc = inc+1
	    if (inc eq 102) then begin
		inc = inc-100
                printf,1,mean_ra,mean_dec,$
                 format = '("     POSITION1:  RA_LON=",f9.6,"d,  DEC_LAT=",f9.6,"d")'
	    endif
	    char = fix(alog10(inc))+1
	    Case char of
	    1: printf,1,inc,coords_off[0,i],coords_off[1,i],$
	       format = '("     OFFSET_P",i1,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")'
	    2: printf,1,inc,coords_off[0,i],coords_off[1,i],$
	       format = '("     OFFSET_P",i2,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")'
	    3: printf,1,inc,coords_off[0,i],coords_off[1,i],$
	       format = '("     OFFSET_P",i3,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")'
	    endcase
	  endfor
	  printf,1,"OFFSETS_IN_ARRAY:  NO"
	  printf,1,"OBSERVE_OFFSETS_ONLY:  YES"
	  printf,1,"OBJECT_AVOIDANCE:  EARTH = YES, OTHERS = YES"
	  printf,1," "
	  printf,1,"          READOUT_MODE: FULL_ARRAY"
; set fov2 if keyword is set
	  if keyword_set('fov2') then begin
	    printf,1,"                 ARRAY: 3.6_5.8u=NO, 4.5_8.0u=YES"
	  endif else begin
	    printf,1,"                 ARRAY: 3.6_5.8u=YES, 4.5_8.0u=NO"
	  endelse
	  printf,1,"            HI_DYNAMIC: YES"
	  printf,1,"            FRAME_TIME: 12.0"
	  printf,1,"        DITHER_PATTERN: TYPE=none"
	  printf,1," N_FRAMES_PER_POINTING: 1"
	  printf,1," SPECIAL: IMPACT = none, LATE_EPHEMERIS = NO,SECOND_LOOK = NO"
	  printf,1," "

; print timing file if keyword is set
	  if keyword_set(timing_file) then begin
	    timing_txt = strarr(5)
	    openr,2,timing_file
            readf,2,timing_txt
	    close,2
	    printf,1,timing_txt[0]
	    printf,1,timing_txt[1]
	    printf,1,timing_txt[2]
	    printf,1,timing_txt[3]
	    printf,1,timing_txt[4]
	  endif
	  close,1
	endif
		
return,coords_off

end
