;
;	clusteroffset
;
;	this program creates an AOR with a cluster offset target ussing a input coordinate
;	file.  This program has a changed order.
;
;	v3 - set up for June 30, 2003 submission of Orion and NGC2264 data.
;       v4 - set up for June 2005 submission of Mon R2 data
;       v5 - set up to correct June 2005 in January 2006
;	S. T. Megeath - adapted Jan 26, 2006 from clusteroffset_v4.pro
;
;              
;
;------------------------------------------------------------------------------------------

function clusteroffset_v9,coords_abs,outfile=outfile,exist=exist,label=label,$
                       incx_step=incx_step,incy_step=incy_step,plot=plot,$
		       target_name=target_name,fov2=fov2,posang=posang,$
                       timing_file=timing_file,follow=follow,aor_ind=aor_ind


        if NOT keyword_set(incx_step) then incx_step = 300.
        if NOT keyword_set(incy_step) then incy_step = 300.
	if NOT keyword_set(label) then label = "IRAC-0001"
	if NOT keyword_set(target_name) then target_name = "none"
        if not keyword_set(posang) then posang=0.
          
        posang2=-1*posang*!pi/180.
        incx_stepd = incx_step/3600.
        incy_stepd = incy_step/3600.

        good = coords_abs
        ncoords = n_elements(coords_abs[0,*])
        index = findgen(ncoords)
	
	if keyword_set(outfile) then begin
	  if NOT keyword_set(exist) then openw,1,outfile
	  if NOT keyword_set(exist) then print,'opening file'
	  if keyword_set(exist) then openw,1,outfile,/append
        endif

        coords_off = coords_abs

          coords_off[0,*] = (coords_abs[0,*]-mean(minmax(coords_abs[0,*])))*cos(2*!pi/360.*mean(minmax(coords_abs[1,*])))
          coords_off[1,*] = coords_abs[1,*]-mean(minmax(coords_abs[1,*]))

        if posang ne 0 then begin 
          coords_off_rot = coords_off
          coords_off_rot[0,*] = coords_off[0,*]*cos(posang2)+coords_off[1,*]*sin(posang2)
          coords_off_rot[1,*] = coords_off[1,*]*cos(posang2)-coords_off[0,*]*sin(posang2)

          coords_off = temporary(coords_off_rot)
        endif

        maxdec = max(coords_off[1,*])-min(coords_off[1,*])
        maxra = (max(coords_off[0,*])-min(coords_off[0,*]))
       tmp1 = ((coords_off[0,*]-shift(coords_off[0,*],-1))[1:ncoords-2])
       incx_stepd = median(abs(tmp1[where(abs(tmp1) gt 1/3600.)]))  
       tmp1 = ((coords_off[1,*]-shift(coords_off[1,*],-1))[1:ncoords-2])
       incy_stepd = 2*median(abs(tmp1[where(abs(tmp1) gt 1/3600.)]))
        if (maxra gt maxdec) then begin
            incx = fix((coords_off[0,*]-min(coords_off[0,*]))/incx_stepd)
            incy = (((coords_off[1,*]-min(coords_off[1,*]))*(abs(incx mod 2) eq 1) + (max(coords_off[1,*])-coords_off[1,*])*(abs(incx mod 2) eq 0))/incy_stepd)
            size = incx*100. + incy
            index = index[sort(size[index])]
      endif else begin
           incy = fix((coords_off[1,*]-min(coords_off[1,*]))/incy_stepd)
           incx = (((coords_off[0,*]-min(coords_off[0,*]))*(abs(incy mod 2) eq 1) + (max(coords_off[0,*])-coords_off[0,*])*(abs(incy mod 2) eq 0))/incx_stepd)
           size = incy*100. + incx
           index = index[sort(size[index])]
      endelse

       if keyword_set(plot) then begin
;            plot,[0],[0],xrange=[max(coords_off[0,*]),min(coords_off[0,*])],$
;                         yrange=[min(coords_off[1,*]),max(coords_off[1,*])]
;            xyouts,coords_off[0,index],coords_off[1,index],string(findgen(n_elements(index)),format='(i4)'),charsize=.8
            plot,[0],[0],xrange=[max(coords_abs[0,*]),min(coords_abs[0,*])],$
                         yrange=[min(coords_abs[1,*]),max(coords_abs[1,*])]
            xyouts,coords_abs[0,index],coords_abs[1,index],string(findgen(n_elements(index)),format='(i4)'),charsize=.8
;            xyouts,coords_abs[0,index],coords_abs[1,index],strtrim(incx[index],2)+','+strtrim(incy[index],2),charsize=.8
       endif
          
       if NOT keyword_set(exist) then  printf,1,'HEADER: FILE_VERSION=7.0, STATUS = PROGRAM'

       inc=1
       if n_elements(aor_ind) eq 0 then aor_ind=0l
       while (index[0] ne -1) do begin
              aortxt = " - 0000" & aor_ind_str = strtrim(aor_ind,2)
              if aor_ind gt 0 then strput,aortxt,aor_ind_str,7-strlen(aor_ind_str) else aortxt = ""
              aor_ind=aor_ind+1

              iaor = index[0:98<(n_elements(index)-1)]

              if (n_elements(index) gt 99) then begin
                  index = index[99:*]
              endif else begin
                  index[0] = -1
              endelse

          ;    mean_ra = mean(coords_abs[0,iaor])
          ;    mean_dec = mean(coords_abs[1,iaor])
              mean_ra = (max(coords_abs[0,iaor])+min(coords_abs[0,iaor]))/2.
              mean_dec = (max(coords_abs[1,iaor])+min(coords_abs[1,iaor]))/2.
              coords_off = coords_abs[*,iaor]
              coords_off[0,*]  = 3600.*(coords_abs[0,iaor]-mean_ra)*cos(2.*!pi*mean_dec/360.)
              coords_off[1,*]  = 3600.*(coords_abs[1,iaor]-mean_dec)
              inc =1
              printf,1,"     AOT_TYPE:  IRAC Mapping"
              printf,1,label,aortxt,format = '("     AOR_LABEL:  ",a,a)'
              printf,1,"    AOR_STATUS:  new"
              printf,1," "
              printf,1," MOVING_TARGET:  NO"
              printf,1,"   TARGET_TYPE:  FIXED CLUSTER - OFFSETS"
              printf,1,target_name,format = '("   TARGET_NAME:  ",a)'
              printf,1,"  COORD_SYSTEM:  Equatorial  J2000"
              printf,1,mean_ra,mean_dec,$
              format = '("     POSITION1:  RA_LON=",f10.6,"d,  DEC_LAT=",f9.6,"d")'
              for i=0,n_elements(iaor)-1 do begin
                inc=inc+1
                char = fix(alog10(inc))+1
                case char of
                    1: printf,1,inc,coords_off[0,i],coords_off[1,i],$
                              format = '("     OFFSET_P",i1,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")'
                    2: printf,1,inc,coords_off[0,i],coords_off[1,i],$
                              format = '("     OFFSET_P",i2,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")'
                    3: printf,1,inc,coords_off[0,i],coords_off[1,i],$
                              format = '("     OFFSET_P",i3,":  EAST_ROW_PERP=",f8.2,%"\,\"       NORTH_COL_PARA=",f8.2,%"\" ")' 
                endcase
              endfor
              printf,1,"OFFSETS_IN_ARRAY:  NO"
              printf,1,"OBSERVE_OFFSETS_ONLY:  YES"
              printf,1,"OBJECT_AVOIDANCE:  EARTH = YES, OTHERS = YES"
              printf,1," "
              printf,1,"          READOUT_MODE: FULL_ARRAY"
; set fov2 if keyword is set
              if keyword_set(fov2) then begin
                  printf,1,"                 ARRAY: 3.6_5.8u=NO, 4.5_8.0u=YES"
              endif else begin
                  printf,1,"                 ARRAY: 3.6_5.8u=YES, 4.5_8.0u=NO"
              endelse
              printf,1,"            HI_DYNAMIC: YES"
              printf,1,"            FRAME_TIME: 12.0"
              printf,1,"        DITHER_PATTERN: TYPE=Cycling, N_POSITION=2, START_POINT=1"
              printf,1,"          DITHER_SCALE: small"
              printf,1," N_FRAMES_PER_POINTING: 1"
              printf,1," SPECIAL: IMPACT = none, LATE_EPHEMERIS = NO,SECOND_LOOK = NO"
              printf,1," "

; print timing file if keyword is set
              if keyword_set(timing_file) then begin
                  timing_txt = strarr(1,2)
                  openr,2,timing_file
                  readf,2,timing_txt
                  close,2
                  printf,1,timing_txt[0,0]
                  printf,1,timing_txt[0,1]
              endif
              if keyword_set(follow) then begin
                  printf,1," "
                  printf,1,"CONSTRAINT: TYPE=FOLLOW_ON, NAME=FollowOn-"+label+aortxt
                  printf,1,"RANGE_START: DAYS=0, TIME=03:00:00"
                  printf,1,"  RANGE_END: DAYS=0, TIME=06:00:00"
                  printf,1,"       AORS: AOR_FIRST="+follow+aortxt+", AOR_SECOND="+label+aortxt
                  printf,1," "

              endif


          endwhile
          close,1
		
return,coords_off


end

