;----------------------------------------------------------------------------
;
;	fmakepoly
;
;	this program produces polygram files which can then be used by finpoly
;	to select cluster points within the polygon.  The polygon can be
;	obtained by either interactively using the cursor on an idl window, or by 
;	reading in a file containing (x,y) coordinates.  Click outside
;	the plotted region but within the IDL window to close the polygon.  The
;	program automatically duplicates the first position at the end of the
;	list of polygon vertices to close the polygon.
;
;	parameters: x  - vector containing ra values for each pixel
;                   y  - vector containing ra values for each pixel
;       keywords    xrange  - xrange (default min(x) to max(x))
;                   yrange  - yrange (default min(y) to max(y))
;		    outfile - ascii file to write polygon coordinates
;		    infile  - ascii file to read in polygon coordinates
;	            plot    - plot polygon after reading infile
;	S. T. Megeath
;
;	3-25-02 - added infile and outfile keywords (S. T. Megeath)
;
;-----------------------------------------------------------------------------


function fmakepoly2,x,y,xrange=xrange,yrange=yrange,outfile=outfile,infile=infile,color=color,plot=plot,hdr=hdr

; set default values    
  poly = replicate(-1000.,2,100)
  tmp = replicate(-1000.,2)           

  oldx = -1000
  oldy = -1000
  firstx = -1000

  firsty = -1000    
  maxx = max(x)
  minx = min(x)
  maxy = max(y)
  miny = min(y)
  inc=0

; set default values for xrange and yrange
  if keyword_set(xrange) then maxx = max(xrange) 
  if keyword_set(xrange) then minx = min(xrange) 
  if keyword_set(yrange) then miny = min(yrange) 
  if keyword_set(yrange) then maxy = max(yrange) 

; open file for writing polygon if keyword is set
  if  keyword_set (outfile) then openw,1,outfile

if keyword_set(infile) and keyword_set(hdr) then begin
	openr,1,infile
	i=-1
        while not eof(1) do begin
          readf,1,tmp
          if i lt 200-1 then i = i + 1 else stop
	  poly[*,i] = tmp
        endwhile
	close,1
	inc = i
        poly = poly[*,0:inc]
        adxy,hdr,poly[0,*],poly[1,*],x,y
        poly[0,*] = x
        poly[1,*] = y
	if keyword_set(plot) then oplot,poly[0,*],poly[1,*],color=color
endif else begin
; start repeat until loop
  repeat begin
    cursor,pixx,pixy,4,/data
    oplot,[pixx],[pixy],psym=2,syms=.2,color=color
    if(pixx le maxx and pixx ge minx and $
       pixy le maxy and pixy ge miny) then begin
       if(oldx ne -1000) then oplot,[pixx,oldx],[pixy,oldy],color=color
       if(oldx eq -1000)  then begin
          firstx = pixx 
          firsty = pixy
       endif
       oldx = pixx
       oldy = pixy
       norep = 0
       help,pixx,pixy
       poly[*,inc] = [pixx,pixy]
       inc = inc+1
    endif else begin
      norep = 1
      if(firstx ne -1000) then oplot,[oldx,firstx],[oldy,firsty],color=color
    endelse
  endrep until norep

; set last polygon position to the first position, and clip poly array to size
; of polygon
  poly[*,inc] = [firstx,firsty]
  poly = poly[*,0:inc]
endelse

; write polygon to file if keyword is set
  if keyword_set(outfile) then begin
        xyad,hdr,poly[0,*],poly[1,*],ra,dec
        poly2 = poly
        poly2[0,*] = ra
        poly2[1,*] = dec
	printf,1,poly2
	close,1
  endif

return,poly
end
