;
; gather_pv program
;
;	PARAMETERS
;
;	xinsize - size of photometry data image
;	yinsize - size of photometry data image
;	scale   - scale factor between photometry image and gather image
;		  (scale = 4 => gather image 1/16 the size of the phot image)
;
;	KEYWORDS
;	 
;	wcs   - structure containings wcs info of image data
;	wcsout - structure containing wcs info of gather plot
;	xpix  - the program will assign to the named variable a vector
;		containing the photimage x pixel value for each gather x pixel
;	ypix  - the program will assign to the named variable a vector
;		containing the photimage y pixel value for each gather y pixel
;	numstars - the number of stars to gather (can be a vector, if you'd 
;                  like multiple maps as output) (default = 7)
;	maglimit - choose stars brigther than maglimit (default = 100)
;	dist     - set to distance in pc (default = 1)
;
; S. T. Megeath 7-12-2003
; R. A. Gutermuth 8-18-03
; R. A. Gutermuth 8-27-03
; R. A. Gutermuth 9-8-03  mean of radial distance
;
;-----------------------------------------------------------------
 
function gather_pv4,pv_dat,xinsize,yinsize,scale,wcs=wcs,xpix=xpix,ypix=ypix,$
	        maglimit=maglimit,numstars=numstars,dist=dist,outwcs=outwcs

; set keyword
  if NOT keyword_set(maglimit) then maglimit = 100
  if NOT keyword_set(numstars) then numstars = 7
  if NOT keyword_set(dist) then dist = 1
  areaconv=1
  nlayers = n_elements(numstars)

; find all stars with magnitudes less than our equal to the mag limit and
; store their xpositions and ypositions

;MOD-RAG
  index = where(pv_dat[7,*] le maglimit,nstars)
;  index = where(pv_dat[7,*] le maglimit)
;  nstars = n_elements(index)
  if nstars lt min(numstars) then begin
   print,'ERROR in gather_pv2.pro: not enough valid sources!!'
   retall
  endif
;END MOD

  xpos = pv_dat[0,index]
  ypos = pv_dat[1,index]
  
; set size of output map
  xoutsize = fix(xinsize/scale)
  youtsize = fix(yinsize/scale)

;MOD-RAG
  xdref = fltarr(nstars,xoutsize,/nozero)
  ydref = fltarr(nstars,youtsize,/nozero)
  image = fltarr(xoutsize,youtsize,nlayers,/nozero)  
;  image = fltarr(xoutsize,youtsize)  
;END MOD

; find conversion from gather map pixels to input mosaic pixels
  xpix = scale*findgen(xoutsize)
  ypix = scale*findgen(youtsize)

; if keyword wcs is set then convert units to stars per deg^2, if wcs and dist is set,
; convert unit to stars per pc^2.
  if keyword_set(wcs) then begin
	cd = wcs.cd
	areaconv = sqrt(cd[0,0]^2+cd[0,1]^2)*sqrt(cd[1,0]^2+cd[1,1]^2)
	if keyword_set(dist) then begin
		areaconv = areaconv*(!pi/180.*dist)^2
	endif
  endif

; find values of wcs
  if keyword_set(outwcs) then begin
	outwcs = wcs
	if keyword_set(wcs) then begin
		outwcs.cd = wcs.cd*scale
		outwcs.radec_center = wcs.radec_center
		outwcs.pix_center[0] = wcs.pix_center[0]/scale
		outwcs.pix_center[1] = wcs.pix_center[1]/scale
	endif else begin
		print,'no input wcs value'
	endelse
  endif

; q = findgen(numstars)            ;A useful index running from 0.0 to numstars-1.0
; w = 0.474833*exp(-(abs(q-((numstars-1)/2))))    ;This is a potential weighting function
; w = 1/(float(numstars))                 ;This is an even weighting function

;MOD-RAG
  for i = 0,xoutsize-1 do xdref[*,i] = xpos-xpix[i]
  for i = 0,youtsize-1 do ydref[*,i] = ypos-ypix[i]
  xdref = temporary(xdref)^2.
  ydref = temporary(ydref)^2.

;  for i = 0,xoutsize-1 do begin
  for j = 0,youtsize-1 do begin
    for i = 0,xoutsize-1 do begin
;      x = xpix(i) 
;      y = ypix(j)
;      dist = sqrt((xpos-x)^2+(ypos-y)^2)

      distsq = xdref[*,i]+ydref[*,j]
      distr = sqrt(distsq)
      binsize=max(distr)/100.

;      dist = dist[sort(dist)]   ;Those distances sorted in ascending order
;      dist = dist[0:numstars]   ;The "numstars" smallest distances, still in ascending order

;MOD2-RAG
      new = histogram(distr,binsize=binsize)
      sum = new
      sum[0] = 0
      k = 0l
      while sum[(k-1)>0] lt max(numstars) do begin
       sum[k] = sum[(k-1)>0] + new[k]
       k = k + 1
      endwhile
      w = where(distr lt k * binsize + min(distr))
      srt = sort(distr[w])

;MOD3-RAG
      if n_elements(mndistsq) eq 0 then mndistsq=fltarr(nlayers)
      for g=0,nlayers-1 do mndistsq[g] = (mean(distr[w[srt[0:numstars[g]-1]]]))^2.

;      area = dist[numstars-1]^2*(areaconv)

;      area = distsq[(sort(distsq))[numstars-1]]*(areaconv)
;      area = distsq[w[srt[numstars-1]]]*(areaconv)

      area = mndistsq*(areaconv)
;END MOD3

;END MOD2

;      image[i,j] = 1/(total((w*3.14159*(dist^2))/(q+0.5)))

      if NOT keyword_set (cubic) then begin
;        image[i,j,*] = numstars/area
        image[i,j,*] = numstars/!pi/area ;MOD-RAG
      endif else begin
;        image[i,j,*] = numstars/(area^1.5)
        image[i,j,*] = numstars/4.*3./!pi/(area^1.5) ;MOD-RAG
      endelse
    endfor
  endfor
 
return,image
end
