;+
; NAME:
;       PHOTMATCH2
;
; PURPOSE:
;       Match detections in multiple bands from PhotVis output files
;
; CALLING SEQUENCE:
;       result = PHOTMATCH2()
;
; INPUTS:
;       NONE (GUI-based)
;
; OPTIONAL INPUTS:
;       NONE
;
; KEYWORDS:
;       TOL - distance tolerance in pixels for detection match
;       OFFSET - 2*(n_bands-1) element vector of offsets between source images
;                from the first band
;       FILTER - string array with filter names of data to be matched
;
; OUTPUTS:
;       result is an n_bands+2 by n_matches element array 
;         [x,y,mag1,mag2(,mag3)]
;
; PROCEDURE CALLS:
;       fits_read, fits_write, fits_open, fits_close, sxpar()
;
; REVISION HISTORY:
;       07-01-02 - initial coding (RAG)
;       11-4-02: bastardized from photmatch (RAG)
;
;-


function photmatch2,tol=tol,offset=offset,filter=filter

 if not keyword_set(tol) then tol = 5.
 if not keyword_set(filter) then filter = ['base','new']
 nf = n_elements(filter)
 if not keyword_set(offset) then offset = fltarr(2*(nf-1))

 data = ptrarr(nf,/alloc)

 for i=0,nf-1 do begin
  name = dialog_pickfile(title='Select '+filter[i]+' PV_DAT file',$
                             /must_exist)
  if name eq '' then begin
   print,'Cancelled...'
   retall
  endif
  restore,name
  if i gt 0 then begin
   pv_dat[0,*] = pv_dat[0,*] + offset[2*(i-1)]
   pv_dat[1,*] = pv_dat[1,*] + offset[1+2*(i-1)]
  endif
  *data[i] = temporary(pv_dat)
 endfor

 sz = size(*data[0])
 k = 0

 for i = 0,sz[2]-1 do begin

  x = (*data[0])[0,i]
  y = (*data[0])[1,i]
  mag = (*data[0])[7,i]
  gdflg = 0

;a hack job, I know, but I don't feel like making a real fix
  ;for j = 1,nf-1 do begin
   j = 1
   dist = sqrt(((*data[j])[0,*]-x)^2+((*data[j])[1,*]-y)^2)
   w = where(dist lt tol,nt)
   if nt gt 0 then begin
  ;endfor

    outnew = fltarr(3*nf+2,nt)
    outnew[0,*]=i&outnew[1,*]=x&outnew[2,*]=y&outnew[3,*]=mag
    outnew[4:5,*]=(*data[j])[0:1,w]&outnew[6,*]=(*data[j])[7,w]
    outnew[7,*] = (nt-1)<1

   if k eq 0 then begin
    out = outnew
   endif else begin
    temp = temporary(out)
    out = fltarr(3*nf+2,k+nt,/nozero)
    out[0,0] = temporary(temp)
    out[0,k] = outnew
   endelse
   k = k+nt
  endif
 endfor

 return,out

end

