pro quick_flat,no_dark=no_dark,stddev=stddev,medflat=medflat

 f = dialog_pickfile(/multiple,title='Select files to go into Flat')
 
 nf = n_elements(f)
 if nf le 1 then begin
  print,'ERROR in quick_flat.pro: Missing file selection(s)!'
  retall
 endif

 if keyword_set(no_dark) then dark = 0. else begin
  dk = dialog_pickfile(title='Select sky or dark frame to subtract')
  if dk eq '' then begin
   print,'Not using dark frame...' 
   dark = 0. 
  endif else begin
   print,'Reading '+dk
   fits_read,dk,dark,dhdr
   dtime = sxpar(dhdr,'INT_S')
  endelse
 endelse

 if not keyword_set(stddev) then stddev = 10.
; if not keyword_set(sm_size) then sm_size = 101

;three steps...  have to read in each image 3 times until I have
;enough RAM to have a big cube in memory

;first, get median of first few images of twiflat-"skyflat"
 print,'Phase 1: Get median image of first few raw images'
 for i = 0,(nf-1 < 4) do begin
  print,'Reading '+f[i]
  fits_read,f[i],im,hdr
  im = temporary(im)-dark
  w = where(im lt 0,nbad)
  if nbad gt 0 then im[w] = 0.
  
  if i eq 0 then begin
   sz = size(im)
   itime = sxpar(hdr,'INT_S')
   if n_elements(dark) gt 1 then dark = (itime / dtime) * temporary(dark)
;   avg = im * 0.
   x = ptr_new(make_array(nf<5,sz[1],sz[2],type=sz[sz[0]+1],/nozero))
   med = fltarr(nf,/nozero)
  endif

;  med[i] = median(im)
  md = median(im) 
;  avg = temporary(avg) + temporary(im) / (med[i] * nf)
  (*x)[i,*,*] = temporary(im) / md
 endfor

 new = xmedian_stack(x)
 ptr_free,x
 avg = temporary(*new)
 ptr_free,new

; avg = median(temporary(avg),21)
; avg = smooth(temporary(avg),sm_size,/edge_truncate)
 tvscl,rebin(avg,256,256)>0<2
 hlp,avg

 print,'Phase 1 Completed!' 

;second, mush around each image and get std deviation image
 print,'Phase 2: Get standard deviation image of raw images'  
 for i = 0,nf-1 do begin
  print,'Reading '+f[i]
  fits_read,f[i],im,hdr
  if i eq 0 then std = im * 0.
; im = smooth((((temporary(im) - dark) / med[i]) - avg),sm_size,/edge_truncate)
  im = temporary(im) - dark
  w = where(im lt 0,nbad)
  if nbad gt 0 then im[w] = 0.
  med[i] = median(im)
  im = (temporary(im) / med[i]) - avg

;median too slow... DAMMIT!!  grrrrr...
;mean smooth not cutting it...  switching to median smooth
;  im = smooth(temporary(im)^2,sm_size,/edge_truncate)
;  im = median(temporary(im)^2,sm_size)

  std = temporary(std) + temporary(im^2)
 endfor

 std = sqrt(temporary(std) / nf)
 smd = median(std)
 w = where(std gt smd,nhi)
 if nhi gt 0 then std[w] = smd
 tvscl,rebin(std,256,256)>0<2,256,0,/dev
 hlp,std

 print,'Phase 2 Completed!'

;third, chop high sig values, keep mask tally, and make final flat
 print,'Phase 3: Mask values beyond +/- '+strtrim(stddev,2)+$
    ' standard deviations and recompute final "mean" image'
 for i = 0,nf-1 do begin
  print,'Reading '+f[i]
  fits_read,f[i],im,hdr
  im = (temporary(im) - dark)
  w = where(im lt 0,nbad)
  if nbad gt 0 then im[w] = 0.
  im = temporary(im) / med[i]
  check = abs(im-avg) / std
  if i eq 0 then begin
   final = im * 0.
   tempmask = where(check gt stddev,nbad) 
   mask = tempmask
  endif else begin
   tempmask = where(check gt stddev,nbad)
   mask = [temporary(mask),tempmask]
   w = where(mask ge 0,nchk)
   if nchk gt 0 then mask = temporary(mask[w])
  endelse
  if nbad gt 0 then im[tempmask] = 0.
  final = temporary(final) + temporary(im)
 endfor

;don't need these anymore
 delvarx,std,check,dark

;calculate n for each pixel using mask tally
 norm = final * 0. + nf
 for i = 0l,n_elements(mask)-1 do norm[mask[i]] = norm[mask[i]] - 1
 w = where(norm le 0,nbad)
 if nbad gt 0 then begin
  norm[w] = 1
  final[w] = 0.
 endif
 tvscl,rebin(norm,256,256)>1<max(norm),0,256,/dev
 hlp,norm 

;get final mean!  WOO HOO!!
 final = temporary(final) / temporary(norm)
 if keyword_set(no_dark) then begin
  scl = median(med)
  avg = avg * scl
  final = final * scl
 endif else scl = 1
 tvscl,rebin(final,256,256)>0<2*scl,256,256,/dev
 hlp,final

 print,'Phase 3 Completed!'

 if keyword_set(medflat) then medhdr = hdr
 sxaddpar,hdr,'HISTORY',strtrim(stddev,2)+' sigma-chopped mean of '+$
    strtrim(nf,2)+' dark and sky subtracted, normalized images'

 yup = 'No'
 while yup eq 'No' do begin

  out = dialog_pickfile(title='Save SCM flat field as?')
  if out eq '' then begin
   print,'Cancelling...'
   retall
  endif
  if not file_test(out) then yup = 'Yes' else yup = dialog_message(/question,$
     out+' exists...  Overwrite?')

  if yup eq 'Yes' then begin
   print,'Writing '+out
   fits_write,out,final,hdr
  endif
 endwhile    

 if keyword_set(medflat) then begin
  sxaddpar,medhdr,'HISTORY','median of '+$
     strtrim(nf,2)+' dark and sky subtracted, normalized images'

  yup = 'No'
  while yup eq 'No' do begin

   out = dialog_pickfile(title='Save MEDIAN flat field as?')
   if out eq '' then begin
    print,'Cancelling...'
    retall
   endif
   if not file_test(out) then yup = 'Yes' else yup = dialog_message(/question,$
      out+' exists...  Overwrite?')

   if yup eq 'Yes' then begin
    print,'Writing '+out
    fits_write,out,avg,medhdr
   endif
  endwhile    
 endif
end
