;+
;
; quick_mag_hist - makes a Magnitude histogram from a PVDAT file.
;
; CALLING SEQUENCE:
;
;  quick_mag_hist,infile=infile,bin_size=bin_size,histdat=histdat,
;                maglimit=maglimit,title=title,xtitle=xtitle,ytitle=ytitle,charsize=charsize
;
;-

pro quick_mag_hist,pv_dat,infile=infile,bin_size=bin_size,error_cap=error_cap,$
                 maglimit=maglimit,histdat=histdat,norm=norm,noise=noise,$
                 title=title,xtitle=xtitle,ytitle=ytitle,charsize=charsize

 if n_elements(pv_dat) eq 0 then begin
  if not keyword_set(infile) then begin
   infile = dialog_pickfile(title='Select PVDAT file',/must_exist)
   if infile eq '' then begin
    print,'Cancelled...'
    return
   endif
  endif
  restore,infile
 endif

 if not keyword_set(maglimit) then maglimit = 25.
 if not keyword_set(error_cap) then error_cap = 95.

 w = where(pv_dat[7,*] lt maglimit and pv_dat[8,*] lt error_cap)

 if not keyword_set(bin_size) then bin_size = .5

 histdat = [0,histogram([0,reform(pv_dat[7,w])],bin=bin_size),0]
 nbins = n_elements(histdat)
 histdat[1] = histdat[1]-1

 bins = (findgen(nbins)-.5) * bin_size

 wh = where(histdat gt 0)
 minplot = min(wh)
 if minplot ge 0 then minplot = bins[minplot]-.5*bin_size else minplot = bins[0]+.5*bin_size
 maxplot = max(wh)
 if maxplot ge 0 then maxplot = bins[maxplot]+.5*bin_size else maxplot = max(bins)-.5*bin_size

; in_area = !pi * long(radpix)^2
; if keyword_set(useall) then out_area = (max(pv_dat[0,*]) - min(pv_dat[0,*])) * $
;    (max(pv_dat[1,*]) - min(pv_dat[1,*])) - in_area else $
;    out_area = !pi * maxdist^2 - in_area
; print,radpix,maxdist,in_area,out_area

; out_hist = temporary(out_hist) * in_area/out_area

 xrange = [minplot,maxplot]
 yrange = [0,max(histdat)]

 if not keyword_set(title) then usetitle = '' else usetitle = title+': '
 numstars = strtrim(fix(total(histdat)+.5),2)

 if keyword_set(norm) then histdat = float(histdat)/float(numstars)

 plot,bins,histdat,psym=10,xrange=xrange,yrange=yrange,/xstyle,$
    title=usetitle+'Magnitude Histogram; '+numstars+' sources',$
    xtitle=xtitle,ytitle=ytitle,charsize=charsize

 duh=histdat
 histdat = fltarr(2,nbins)
 histdat[0,*] = bins
 histdat[1,*] = duh

 if keyword_set(noise) then quick_mag_noise,pv_dat,tit=usetitle+'Magnitude vs Noise',xtit=xtitle,ytit=xtitle,xran=xrange,charsize=charsize,error_cap=error_cap,yran=[0,error_cap]

end
