;+
;
; quick_mag_noise - makes a Magnitude vs noise plot from a PVDAT file.
;
; CALLING SEQUENCE:
;
;  quick_mag_noise,infile=infile,bin_size=bin_size,histdat=histdat,
;                maglimit=maglimit,title=title,xtitle=xtitle,ytitle=ytitle,charsize=charsize
;
;-

pro quick_mag_noise,pv_dat,infile=infile,error_cap=error_cap,maglimit=maglimit,$
                 title=title,xtitle=xtitle,ytitle=ytitle,charsize=charsize,$
                 xrange=xrange,yrange=yrange

 if n_elements(pv_dat) eq 0 then begin
  if not keyword_set(infile) then begin
   infile = dialog_pickfile(title='Select PVDAT file',/must_exist)
   if infile eq '' then begin
    print,'Cancelled...'
    return
   endif
  endif
  restore,infile
 endif

 if keyword_set(error_cap) then begin
  w = where(pv_dat[8,*] lt error_cap,ngd)
  if ngd eq 0 then begin
   print,'No valid entries due to error cap'
   retall
  endif
  pv_dat = pv_dat[*,w]
 endif

 if keyword_set(maglimit) then begin
  w = where(pv_dat[7,*] lt maglimit,ngd)
  if ngd eq 0 then begin
   print,'No valid entries due to magnitude limit'
   retall
  endif
  pv_dat = pv_dat[*,w]
 endif

 plot,pv_dat[7,*],pv_dat[8,*],xtitle=xtitle,ytitle=ytitle,title=title,psym=7,syms=.5,charsize=charsize,xrange=xrange,yrange=yrange,/xstyle

end
