
function pv_fwhm2, rad, prof, splrad, splprof

; given a radial profile (counts vs radius) will use
; a spline to extract the FWHM
;
; ALGORITHM
;   finds peak in radial profile, then marches along until finds
;   where radial profile has dropped to half of that,
;   assumes peak value of radial profile is at minimum radius
;
; original version by M. Liu, adapted for ATV by AJB
; then adapted for PhotVis by RAG!!  (how sloppy is this?!)

 nrad = n_elements(rad)

; check the peak
 w = where(prof eq max(prof))
; if float(rad(w[0])) ne min(rad) then begin
;  photwarning = dialog_message('Profile peak is off-center!')
;  return,-1
; endif

; interpolate radial profile at 50 times as many points
 splrad = min(rad) + findgen(nrad*50+1) * (max(rad)-min(rad)) / (nrad*50)
 nspl = n_elements(splrad)

; spline the profile
 splprof = spline(rad,prof,splrad)

; march along splined profile until cross 0.5*peak value
 found = 0
 i = 0
 repeat begin
  if splprof(i) lt 0.5*max(splprof) then $
        found = 1 $
  else $
        i = i+1
 endrep until ((found) or (i eq nspl))

 if (i lt 2) or (i eq nspl) then begin
;  photwarning = dialog_message('Unable to measure FWHM!')
  return,-1
 endif

; now interpolate across the 2 points straddling the 0.5*peak
 fwhm = splrad(i)+splrad(i-1)

 return,fwhm
end

