;+
;   name:
; 	loadlist.pro
;
;   purpose:
;	This function loads in a list of image names given in a list
;	file and returns the list in the form of a string array.
;
;	If there is no data - then stringlist returns a single element
;	array with "no_data"
;
;   calling sequence:
;       stringlist = loadlist(stringdata, max=max)
;
;   inputs:
;	stringdata = list of image names, one per line
;	max = keyword indicating maximum size of list (default = 1000)
;
;   output:
;       result = the list in the form of a string array
;
;   note:
;       generally loadlist.pro isn't used on its own--just called by
;       other programs.
;
;   history:
;	written 09/2000: S. T. Megeath
;       last modified: 12-6-2000 by S. T. Megeath
;
;-

function loadlist,stringdata,max=max

; set up keywords
  if NOT keyword_set(max) then  max = 1000

;create list variable and then open listname
  i = 0
  tmp = ' '
  stringlist = replicate(' ',1000)
  openr,1,stringdata
 
;then, loop through and read each string in listname
  while not eof(1) do begin
    readf,1,tmp
    stringlist[i] = tmp
    if i lt max then i = i + 1 else stop
  endwhile
 
;trim array and close - if there is no data, then replace stringlist
;with no_data
  if (i ge 1) then begin
    stringlist = stringlist[0:i-1]
    nlist = i-1
  endif else begin
    stringlist = ["no_data"]
  endelse
  close,1

  return,stringlist

  end
