;+
;  name:
;         median_stack2.pro
;
;  purpose:
;         Median filters a stack of images.  (Wanna ignore some pixels?
;         Set them to NaN and the IDL median function ignores them!)
;
;  calling sequence:
;         result = median_stack(datacube)
;
;  inputs:
;         datacube = stack of data "on its side" such that each image
;                    is parallel to the Y-Z plane : 3d data cube [k,i,j]
;
;  keywords:
;         NONE
;
;  output:
;         result = a 2d image containing the median pixel values
;
;  called programs:
;         NONE
;
;  history:
;         written by S. T. Megeath - summer 1998
;         last modified 12-28-98
;         2-12-02 - major modifications: now expecting pointer to
;                   datacube which we will median along the X
;                   direction...  also indexed things to follow
;                   vector order of array. (RAG)
;         3-4-02 - ditched pointer usage per Tom's request (RAG)
;         11-10-03 - added use of new DIMENSION keyword if IDL 5.6
;                    or greater.  (RAG)
;
;-

function median_stack2,datacube

;if IDL 5.6 or later, median function has DIMENSION keyword
;to do this stuff for us finally!

 if !version.release ge 5.6 then begin
  med = median(datacube,dim=1,/even)

 endif else begin

;find the size of one image and create final data array
  sz = size(datacube)
  med = make_array(sz[2],sz[3],type=sz[sz[0]+1],/nozero)

;for every pixel in the data array, calculate the median
  for j = 0, sz[3]-1 do for i = 0, sz[2]-1 do med[i,j] = $
     median(datacube[*,i,j],/even)
 endelse

 return,med

end


