;----------------------------------------------------------------
;
;   This program overlays a CO data cube onto an image
;
;----------------------------------------------------------------

pro contour_cube,cubename,$
  l0=l0,b0=b0,dl=dl,db=db,vel1=vel1,vel2=vel2,moment=moment,$
  contour=contour,plotpos=plotpos,order=order,percent=percent,$
  points=points,mag=mag

  if NOT keyword_set(order) then order = "vxy"
  if NOT keyword_set(order) then percent = 0
  if NOT keyword_set(order) then mag = 1

; read in image and convert to bytscale 
  fits_read,cubename,cube,header

; determine velocity channel spacing
  fitsaxes,header,x,y,z,/iraf,order=order
  nx = n_elements(x)
  ny = n_elements(y)

; integrate cube over velocity range
  sum = int_slice(cube,header,vel1=vel1,vel2=vel2,$
        moment=moment,order=order)
  
; find lower left hand and upper right hand pixels.
  pixll = 0 > $
   [fix((l0+dl/2.-x[0])/(x[1]-x[0])),fix((b0-db/2.-y[0])/(y[1]-y[0]))] < nx-1
  pixur = 0 > $
    [fix((l0-dl/2.-x[0])/(x[1]-x[0])),fix((b0+db/2.-y[0])/(y[1]-y[0]))] < ny-1
  siz = abs(pixur-pixll)+[1,1]
  xnew = rebin(x[(pixll[0] < pixur[0]):(pixll[0] > pixur[0])],mag*siz[0])
  ynew = rebin(y[(pixll[1] < pixur[1]):(pixll[1] > pixur[1])],mag*siz[1])

; interpolate sum onto new grid
  xinterp = interp_pix(xnew,x)
  yinterp = interp_pix(ynew,y)
  sum = interpolate(sum,xinterp,yinterp,/grid,missing=0)

; set contour levels
  if not keyword_set(contour) then begin
    contour = [.3,.4,.5,.6,.7,.8,.9,1.0]*max(sum)
  endif else begin
    if percent eq 1 then contour=contour*max(sum)
  endelse
  print,contour

; set up plotting window
  xtest=findgen(256) & ytest=findgen(256)
  if keyword_set(plotpos) then begin
    n = 1
    plot,xtest,ytest,xsty=5,ysty=5,/nodata,/noerase,pos=plotpos,/device
    px=!x.window*!d.x_vsize
    py=!y.window*!d.y_vsize
    xsize = px[1]-px[0] & ysize=py[1]-py[0]
  endif else begin
    n = fix(1.*min([!d.x_vsize*.9,!d.y_vsize*.9])/max(siz))
    print,n,siz,!d.x_vsize,!d.y_vsize
    plot,xtest,ytest,/nodata,xstyle=5,ystyle=5
    px=!x.window*!d.x_vsize
    py=!y.window*!d.y_vsize
    xsize = n*siz[0]-1
    ysize = n*siz[1]-1
    plotpos = replicate(0,4)
    plotpos[0] = px[0]
    plotpos[1] = py[0]
    plotpos[2] = px[0]+xsize
    plotpos[3] = py[0]+ysize
   endelse

; contour data
  contour,sum,xnew,ynew,$
       position=plotpos, xstyle=1,ystyle=1,$
       levels=contour, yrange= [min(ynew),max(ynew)],$
       xrange=[max(xnew),min(xnew)],/device,/noerase

; plot data point positions
  if keyword_set(points) then begin
   oplot,points[0,*],points[1,*],psym=3
  endif

return
end

