; 
;	xyv2vxy
;	
;	this program transposes xyv cubes to vxy cubes.  Currently there is no checking
;	that the input cube is in xyv, the user must be cautious about the format of the input 
;	file.
;
;	parameters:	 infile  - input file
;			 outfile - output file
;
;	4-28-2003 S. T. Megeath
;
;------------------------------------------------------------------------------

pro xyv2vxy,infile,outfile

; load in data and header
	fits_read,infile,data,header,/NaN

; transpose data
	outdata = transpose(data,[2,0,1])

; transpose header
	outheader = header

; load in RA parameters
	ctype_ra = strmid(outheader[where(strmid(outheader,0,6) eq "CTYPE1")],10,20)
	crval_ra = strmid(outheader[where(strmid(outheader,0,6) eq "CRVAL1")],10,20)
	cdelt_ra = strmid(outheader[where(strmid(outheader,0,6) eq "CDELT1")],10,20)
	crpix_ra = strmid(outheader[where(strmid(outheader,0,6) eq "CRPIX1")],10,20)
	if (where(strmid(outheader,0,6) eq "CROTA1") ne -1) then $
	crota_ra = strmid(outheader[where(strmid(outheader,0,6) eq "CROTA1")],10,20)

; load in dec parameters
	ctype_dec = strmid(outheader[where(strmid(outheader,0,6) eq "CTYPE2")],10,20)
	crval_dec = strmid(outheader[where(strmid(outheader,0,6) eq "CRVAL2")],10,20)
	cdelt_dec = strmid(outheader[where(strmid(outheader,0,6) eq "CDELT2")],10,20)
	crpix_dec = strmid(outheader[where(strmid(outheader,0,6) eq "CRPIX2")],10,20)
	if (where(strmid(outheader,0,6) eq "CROTA2") ne -1) then $
	crota_dec = strmid(outheader[where(strmid(outheader,0,6) eq "CROTA2")],10,20)

; load in velocity parameters
	ctype_vel = strmid(outheader[where(strmid(outheader,0,6) eq "CTYPE3")],10,20)
	crval_vel = strmid(outheader[where(strmid(outheader,0,6) eq "CRVAL3")],10,20)
	cdelt_vel = strmid(outheader[where(strmid(outheader,0,6) eq "CDELT3")],10,20)
	crpix_vel = strmid(outheader[where(strmid(outheader,0,6) eq "CRPIX3")],10,20)
	if (where(strmid(outheader,0,6) eq "CROTA3") ne -1) then $
	crota_vel = strmid(outheader[where(strmid(outheader,0,6) eq "CROTA3")],10,20)

; write velocity parameters
	tmp = outheader[where(strmid(outheader,0,6) eq "CTYPE1")]
	strput,tmp,ctype_vel,10	
	outheader[where(strmid(outheader,0,6) eq "CTYPE1")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRVAL1")]
	strput,tmp,crval_vel,10	
	outheader[where(strmid(outheader,0,6) eq "CRVAL1")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CDELT1")]
	strput,tmp,cdelt_vel,10	
	outheader[where(strmid(outheader,0,6) eq "CDELT1")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRPIX1")]
	strput,tmp,crpix_vel,10	
	outheader[where(strmid(outheader,0,6) eq "CRPIX1")] = tmp
	if (where(strmid(outheader,0,6) eq "CROTA1") ne -1) then begin
		tmp = outheader[where(strmid(outheader,0,6) eq "CROTA1")]
		strput,tmp,crota_vel,10	
		outheader[where(strmid(outheader,0,6) eq "CROTA1")] = tmp
	endif

; write RA parameters
	tmp = outheader[where(strmid(outheader,0,6) eq "CTYPE2")]
	strput,tmp,ctype_ra,10	
	outheader[where(strmid(outheader,0,6) eq "CTYPE2")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRVAL2")]
	strput,tmp,crval_ra,10	
	outheader[where(strmid(outheader,0,6) eq "CRVAL2")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CDELT2")]
	strput,tmp,cdelt_ra,10	
	outheader[where(strmid(outheader,0,6) eq "CDELT2")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRPIX2")]
	strput,tmp,crpix_ra,10	
	outheader[where(strmid(outheader,0,6) eq "CRPIX2")] = tmp
	if (where(strmid(outheader,0,6) eq "CROTA2") ne -1) then begin
		tmp = outheader[where(strmid(outheader,0,6) eq "CROTA2")]
		strput,tmp,crota_ra,10	
		outheader[where(strmid(outheader,0,6) eq "CROTA2")] = tmp
	endif

; write dec parameters
	tmp = outheader[where(strmid(outheader,0,6) eq "CTYPE3")]
	strput,tmp,ctype_dec,10	
	outheader[where(strmid(outheader,0,6) eq "CTYPE3")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRVAL3")]
	strput,tmp,crval_dec,10	
	outheader[where(strmid(outheader,0,6) eq "CRVAL3")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CDELT3")]
	strput,tmp,cdelt_dec,10	
	outheader[where(strmid(outheader,0,6) eq "CDELT3")] = tmp
	tmp = outheader[where(strmid(outheader,0,6) eq "CRPIX3")]
	strput,tmp,crpix_dec,10	
	outheader[where(strmid(outheader,0,6) eq "CRPIX3")] = tmp
	if (where(strmid(outheader,0,6) eq "CROTA3") ne -1) then begin
		tmp = outheader[where(strmid(outheader,0,6) eq "CROTA3")]
		strput,tmp,crota_dec,10	
		outheader[where(strmid(outheader,0,6) eq "CROTA3")] = tmp
	endif


	fits_write,outfile,outdata,outheader

	return
end


